This is the mail archive of the binutils@sources.redhat.com mailing list for the binutils project.


Index Nav: [Date Index] [Subject Index] [Author Index] [Thread Index]
Message Nav: [Date Prev] [Date Next] [Thread Prev] [Thread Next]
Other format: [Raw text]

[patch] binutils: Fix comment typos.


Hi,

Attached is a patch to fix comment typos.  Committed as obvious.

Kazu Hirata

2003-10-27  Kazu Hirata  <kazu@cs.umass.edu>

	* ChangeLog: Fix typos.
	* ChangeLog-9197: Likewise.
	* ChangeLog-9899: Likewise.
	* NEWS: Likewise.
	* ar.c: Fix comment typos.
	* arsup.c: Likewise.
	* coffgrok.c: Likewise.
	* debug.c: Likewise.
	* debug.h: Likewise.
	* dlltool.c: Likewise.
	* ieee.c: Likewise.
	* nm.c: Likewise.
	* objdump.c: Likewise.
	* prdbg.c: Likewise.
	* readelf.c: Likewise.
	* resrc.c: Likewise.
	* sysinfo.y: Likewise.
	* windres.c: Likewise.

Index: ChangeLog
===================================================================
RCS file: /cvs/src/src/binutils/ChangeLog,v
retrieving revision 1.703
diff -u -r1.703 ChangeLog
--- ChangeLog	21 Oct 2003 14:08:12 -0000	1.703
+++ ChangeLog	27 Oct 2003 13:10:44 -0000
@@ -334,9 +334,9 @@
 2003-06-27  Nick Clifton  <nickc@redhat.com>
 
 	* objcopy.c (copy_object): Replace call to
-	bfd_create_gnu_debuglink_section with seperate calls to
+	bfd_create_gnu_debuglink_section with separate calls to
 	bfd_add_gnu_debuglink_section and
-	bfd_fill_in_gnu_debuglink_section, seperated by a walk over the
+	bfd_fill_in_gnu_debuglink_section, separated by a walk over the
 	symbol tables.
 
 2003-06-26  Roland McGrath  <roland@redhat.com>
@@ -851,7 +851,7 @@
 
 	* objcopy.c: Add --prefix-symbols=<prefix> option to rename all
 	symbols by adding the given prefix to the begining of the symbol
-	name. This is useful to provide name space seperation regardless
+	name. This is useful to provide name space separation regardless
 	of how the object file was created. Added --prefix-sections=
 	<prefix> and --prefix-alloc-sections=<prefix> options to rename all
 	sections (or all sections with the alloc flag set) by adding the given
@@ -1360,7 +1360,7 @@
 
 2002-6-13  Elias Athanasopoulos  <eathan@otenet.gr>
 
-	* nm.c (struct extended_symbol_info): New strcuture: Add the size
+	* nm.c (struct extended_symbol_info): New structure: Add the size
 	of the symbols to the information provided by the symbol_info
 	structure.
 	(print_symbols): Pass the symbol size to print_symbol.
@@ -3273,7 +3273,7 @@
 2000-08-14  Todd Vierling <tv@wasabisystems.com>
 
 	* objcopy.c (strip_main): Silently accept -d as an alias for -g
-	for compatability with old BSD systems.
+	for compatibility with old BSD systems.
 
 2000-08-14  Jason Eckhardt  <jle@cygnus.com>
 
Index: ChangeLog-9197
===================================================================
RCS file: /cvs/src/src/binutils/ChangeLog-9197,v
retrieving revision 1.3
diff -u -r1.3 ChangeLog-9197
--- ChangeLog-9197	28 May 2001 10:37:49 -0000	1.3
+++ ChangeLog-9197	27 Oct 2003 13:10:47 -0000
@@ -2394,7 +2394,7 @@
 	* nlmconv.c (powerpc_mangle_relocs): Cast memset arg to size_t.
 	* objcopy.c (copy_object): Likewise.
 
-	* nm.c (HAVE_SBRK): Define execpt on amigados and WINDOWS_NT.
+	* nm.c (HAVE_SBRK): Define except on amigados and WINDOWS_NT.
 	(struct size_sym): Define.
 	(show_stats): New static variable.
 	(long_options): Add undocumented option "stats".
Index: ChangeLog-9899
===================================================================
RCS file: /cvs/src/src/binutils/ChangeLog-9899,v
retrieving revision 1.1
diff -u -r1.1 ChangeLog-9899
--- ChangeLog-9899	11 Jan 2001 19:01:41 -0000	1.1
+++ ChangeLog-9899	27 Oct 2003 13:10:48 -0000
@@ -552,7 +552,7 @@
 
 1999-06-04  Nick Clifton  <nickc@cygnus.com>
 
-	* readelf.c: Use 64bit wide fields in internal strcutures even if
+	* readelf.c: Use 64bit wide fields in internal structures even if
 	targetting a 32bit architecture.
 	(dump_relocations): Take a new parameter - the number of symbols
 	in the symbol table.
Index: NEWS
===================================================================
RCS file: /cvs/src/src/binutils/NEWS,v
retrieving revision 1.40
diff -u -r1.40 NEWS
--- NEWS	30 Sep 2003 16:44:03 -0000	1.40
+++ NEWS	27 Oct 2003 13:10:49 -0000
@@ -13,7 +13,7 @@
 
 * objcopy now accepts --add-gnu-debuglink=<file> to insert a .gnu_debuglink
   section into a (presumably stripped) executable.  This allows the debug
-  information for the file to be held in a seperate file.
+  information for the file to be held in a separate file.
   
 * BFD marks the sections .comment and .note as 'n' in the BSD/POSIX
   single-character representation.  This can be checked by running nm
Index: ar.c
===================================================================
RCS file: /cvs/src/src/binutils/ar.c,v
retrieving revision 1.28
diff -u -r1.28 ar.c
--- ar.c	14 Sep 2003 12:20:16 -0000	1.28
+++ ar.c	27 Oct 2003 13:10:49 -0000
@@ -24,7 +24,7 @@
    should have long options too. GNU ar used to check file against filesystem
    in quick_update and replace operations (would check mtime). Doesn't warn
    when name truncated. No way to specify pos_end. Error messages should be
-   more consistant.  */
+   more consistent.  */
 
 #include "bfd.h"
 #include "libiberty.h"
@@ -103,7 +103,7 @@
 
 /* Controls the writing of an archive symbol table (in BSD: a __.SYMDEF
    member).  -1 means we've been explicitly asked to not write a symbol table;
-   +1 means we've been explictly asked to write it;
+   +1 means we've been explicitly asked to write it;
    0 is the default.
    Traditionally, the default in BSD has been to not write the table.
    However, for POSIX.2 compliance the default is now to write a symbol table
@@ -991,7 +991,7 @@
   if (ar_truncate)
     temp->flags |= BFD_TRADITIONAL_FORMAT;
 
-  /* assume it's an achive, go straight to the end, sans $200 */
+  /* assume it's an archive, go straight to the end, sans $200 */
   fseek (ofile, 0, 2);
 
   for (; files_to_append && *files_to_append; ++files_to_append)
Index: arsup.c
===================================================================
RCS file: /cvs/src/src/binutils/arsup.c,v
retrieving revision 1.10
diff -u -r1.10 arsup.c
--- arsup.c	14 Sep 2003 12:20:16 -0000	1.10
+++ arsup.c	27 Oct 2003 13:10:49 -0000
@@ -235,7 +235,7 @@
       if (arch != NULL)
 	map_over_list (arch, ar_addlib_doer, list);
 
-      /* Don't close the bfd, since it will make the elements disasppear.  */
+      /* Don't close the bfd, since it will make the elements disappear.  */
     }
 }
 
Index: coffgrok.c
===================================================================
RCS file: /cvs/src/src/binutils/coffgrok.c,v
retrieving revision 1.7
diff -u -r1.7 coffgrok.c
--- coffgrok.c	14 Sep 2003 12:20:16 -0000	1.7
+++ coffgrok.c	27 Oct 2003 13:10:49 -0000
@@ -370,7 +370,7 @@
 	{
 	  if (aux->x_sym.x_tagndx.p)
 	    {
-	      /* Refering to a struct defined elsewhere */
+	      /* Referring to a struct defined elsewhere */
 	      res->type = coff_structref_type;
 	      res->u.astructref.ref = tindex[INDEXOF (aux->x_sym.x_tagndx.p)];
 	      res->size = res->u.astructref.ref ?
@@ -389,7 +389,7 @@
 	}
       else
 	{
-	  /* No auxents - it's anonynmous */
+	  /* No auxents - it's anonymous */
 	  res->type = coff_structref_type;
 	  res->u.astructref.ref = 0;
 	  res->size = 0;
Index: debug.c
===================================================================
RCS file: /cvs/src/src/binutils/debug.c,v
retrieving revision 1.11
diff -u -r1.11 debug.c
--- debug.c	14 Sep 2003 12:20:16 -0000	1.11
+++ debug.c	27 Oct 2003 13:10:50 -0000
@@ -22,7 +22,7 @@
 /* This file implements a generic debugging format.  We may eventually
    have readers which convert different formats into this generic
    format, and writers which write it out.  The initial impetus for
-   this was writing a convertor from stabs to HP IEEE-695 debugging
+   this was writing a converter from stabs to HP IEEE-695 debugging
    format.  */
 
 #include <stdio.h>
Index: debug.h
===================================================================
RCS file: /cvs/src/src/binutils/debug.h,v
retrieving revision 1.5
diff -u -r1.5 debug.h
--- debug.h	14 Sep 2003 12:20:16 -0000	1.5
+++ debug.h	27 Oct 2003 13:10:51 -0000
@@ -25,7 +25,7 @@
 /* This header file describes a generic debugging information format.
    We may eventually have readers which convert different formats into
    this generic format, and writers which write it out.  The initial
-   impetus for this was writing a convertor from stabs to HP IEEE-695
+   impetus for this was writing a converter from stabs to HP IEEE-695
    debugging format.  */
 
 /* Different kinds of types.  */
Index: dlltool.c
===================================================================
RCS file: /cvs/src/src/binutils/dlltool.c,v
retrieving revision 1.44
diff -u -r1.44 dlltool.c
--- dlltool.c	15 Sep 2003 14:40:44 -0000	1.44
+++ dlltool.c	27 Oct 2003 13:10:52 -0000
@@ -60,7 +60,7 @@
    Declares that <external-name> or the exported function whoes ordinal number
    is <integer> is to be imported from the file <module-name>.  If
    <internal-name> is specified then this is the name that the imported
-   function will be refered to in the body of the DLL.
+   function will be refereed to in the body of the DLL.
 
    DESCRIPTION <string>
    Puts <string> into output .exp file in the .rdata section
@@ -443,7 +443,7 @@
 #define TMP_TAIL_O	dlltmp (&tmp_tail_o_buf, "%st.o")
 #define TMP_STUB	dlltmp (&tmp_stub_buf, "%ss")
 
-/* This bit of assemly does jmp * ....  */
+/* This bit of assembly does jmp * ....  */
 static const unsigned char i386_jtab[] =
 {
   0xff, 0x25, 0x00, 0x00, 0x00, 0x00, 0x90, 0x90
@@ -1943,7 +1943,7 @@
 	  int dst = 0;
 	  int last = -1;
 	  qsort (copy, num_entries, sizeof (long), sfunc);
-	  /* Delete duplcates */
+	  /* Delete duplicates */
 	  for (src = 0; src < num_entries; src++)
 	    {
 	      if (last != copy[src])
@@ -2364,7 +2364,7 @@
       ptrs[oidx++] = iname_lab;
 
 #ifdef DLLTOOL_PPC
-      /* The symbol refering to the code (.text).  */
+      /* The symbol referring to the code (.text).  */
       {
 	asymbol *function_name;
 
@@ -3160,7 +3160,7 @@
   {"exclude-symbols", required_argument, NULL, OPTION_EXCLUDE_SYMS},
   {"no-default-excludes", no_argument, NULL, OPTION_NO_DEFAULT_EXCLUDES},
   {"output-lib", required_argument, NULL, 'l'},
-  {"def", required_argument, NULL, 'd'}, /* for compatiblity with older versions */
+  {"def", required_argument, NULL, 'd'}, /* for compatibility with older versions */
   {"input-def", required_argument, NULL, 'd'},
   {"add-underscore", no_argument, NULL, 'U'},
   {"kill-at", no_argument, NULL, 'k'},
Index: ieee.c
===================================================================
RCS file: /cvs/src/src/binutils/ieee.c,v
retrieving revision 1.13
diff -u -r1.13 ieee.c
--- ieee.c	14 Sep 2003 12:20:16 -0000	1.13
+++ ieee.c	27 Oct 2003 13:10:55 -0000
@@ -6036,7 +6036,7 @@
 	  && ! ieee_buffer_emptyp (&info->type_stack->type.strdef));
 
   /* If we were ignoring this struct definition because it was a
-     duplicate defintion, just through away whatever bytes we have
+     duplicate definition, just through away whatever bytes we have
      accumulated.  Leave the type on the stack.  */
   if (info->type_stack->type.ignorep)
     return TRUE;
Index: nm.c
===================================================================
RCS file: /cvs/src/src/binutils/nm.c,v
retrieving revision 1.37
diff -u -r1.37 nm.c
--- nm.c	14 Sep 2003 12:20:16 -0000	1.37
+++ nm.c	27 Oct 2003 13:10:55 -0000
@@ -444,7 +444,7 @@
 	  break;
 	case 'X':
 	  /* Ignored for (partial) AIX compatibility.  On AIX, the
-	     argument has values 32, 64, or 32_64, and specfies that
+	     argument has values 32, 64, or 32_64, and specifies that
 	     only 32-bit, only 64-bit, or both kinds of objects should
 	     be examined.  The default is 32.  So plain AIX nm on a
 	     library archive with both kinds of objects will ignore
@@ -1442,7 +1442,7 @@
   else
     {
       /* Normally we print the value of the symbol.  If we are printing the
-	 size or sorting by size then we print its size, execpt for the
+	 size or sorting by size then we print its size, except for the
 	 (weird) special case where both flags are defined, in which case we
 	 print both values.  This conforms to documented behaviour.  */
       if (sort_by_size && !print_size)
Index: prdbg.c
===================================================================
RCS file: /cvs/src/src/binutils/prdbg.c,v
retrieving revision 1.8
diff -u -r1.8 prdbg.c
--- prdbg.c	14 Sep 2003 12:20:16 -0000	1.8
+++ prdbg.c	27 Oct 2003 13:10:57 -0000
@@ -267,7 +267,7 @@
   tg_start_class_type,
   tg_class_static_member,
   tg_class_baseclass,
-  pr_class_start_method,	/* Same, remmembers that's a method.  */
+  pr_class_start_method,	/* Same, remembers that's a method.  */
   tg_class_method_variant,
   tg_class_static_method_variant,
   pr_class_end_method,		/* Same, forgets that's a method.  */
Index: readelf.c
===================================================================
RCS file: /cvs/src/src/binutils/readelf.c,v
retrieving revision 1.221
diff -u -r1.221 readelf.c
--- readelf.c	30 Sep 2003 16:17:11 -0000	1.221
+++ readelf.c	27 Oct 2003 13:11:01 -0000
@@ -310,7 +310,7 @@
       /* This is a special case, generated by the BYTE_GET8 macro.
 	 It means that we are loading an 8 byte value from a field
 	 in an external structure into an 8 byte value in a field
-	 in an internal strcuture.  */
+	 in an internal structure.  */
       return  ((bfd_vma) (field[0]))
 	|    (((bfd_vma) (field[1])) << 8)
 	|    (((bfd_vma) (field[2])) << 16)
@@ -536,7 +536,7 @@
       /* This is a special case, generated by the BYTE_GET8 macro.
 	 It means that we are loading an 8 byte value from a field
 	 in an external structure into an 8 byte value in a field
-	 in an internal strcuture.  */
+	 in an internal structure.  */
       return ((bfd_vma) (field[7]))
 	|   (((bfd_vma) (field[6])) << 8)
 	|   (((bfd_vma) (field[5])) << 16)
@@ -6847,7 +6847,7 @@
     }
 }
 
-/* FIXME:  There are better and more effiecint ways to handle
+/* FIXME:  There are better and more efficient ways to handle
    these structures.  For now though, I just want something that
    is simple to implement.  */
 typedef struct abbrev_attr
@@ -7541,7 +7541,7 @@
 	  /* Normally, the lists in the debug_loc section are related to a
 	     given compilation unit, and thus, we would use the pointer size
 	     of that compilation unit.  However, since we are displaying it
-	     seperately here, we either have to store pointer sizes of all
+	     separately here, we either have to store pointer sizes of all
 	     compilation units, or assume they don't change.   We assume,
 	     like the debug_line display, that it doesn't change.  */
 	  begin = byte_get (start, debug_line_pointer_size);
@@ -7843,7 +7843,7 @@
       break;
     }
 
-  /* For some attributes we can display futher information.  */
+  /* For some attributes we can display further information.  */
 
   printf ("\t");
 
@@ -10135,7 +10135,7 @@
       /* If we have been compiled with sizeof (bfd_vma) == 4, then
 	 we will not be able to cope with the 64bit data found in
 	 64 ELF files.  Detect this now and abort before we start
-	 overwritting things.  */
+	 overwriting things.  */
       if (sizeof (bfd_vma) < 8)
 	{
 	  error (_("This instance of readelf has been built without support for a\n\
Index: resrc.c
===================================================================
RCS file: /cvs/src/src/binutils/resrc.c,v
retrieving revision 1.24
diff -u -r1.24 resrc.c
--- resrc.c	2 Oct 2003 14:13:10 -0000	1.24
+++ resrc.c	27 Oct 2003 13:11:02 -0000
@@ -251,7 +251,7 @@
   /* Restore stdout to its previous setting.  */
   dup2 (stdout_save, STDOUT_FILENO);
 
-  /* Close reponse file.  */
+  /* Close response file.  */
   close (redir_handle);
 
   if (pid == -1)
Index: sysinfo.y
===================================================================
RCS file: /cvs/src/src/binutils/sysinfo.y,v
retrieving revision 1.4
diff -u -r1.4 sysinfo.y
--- sysinfo.y	14 Sep 2003 12:20:17 -0000	1.4
+++ sysinfo.y	27 Oct 2003 13:11:02 -0000
@@ -406,7 +406,7 @@
 %%
 /* four modes
 
-   -d write structure defintions for sysroff in host format
+   -d write structure definitions for sysroff in host format
    -i write functions to swap into sysroff format in
    -o write functions to swap into sysroff format out
    -c write code to print info in human form */
Index: windres.c
===================================================================
RCS file: /cvs/src/src/binutils/windres.c,v
retrieving revision 1.19
diff -u -r1.19 windres.c
--- windres.c	14 Sep 2003 12:20:17 -0000	1.19
+++ windres.c	27 Oct 2003 13:11:02 -0000
@@ -788,7 +788,7 @@
 	  break;
 
 	case 'f':
-	  /* For compatability with rc we accept "-fo <name>" as being the
+	  /* For compatibility with rc we accept "-fo <name>" as being the
 	     equivalent of "-o <name>".  We do not advertise this fact
 	     though, as we do not want users to use non-GNU like command
 	     line switches.  */


Index Nav: [Date Index] [Subject Index] [Author Index] [Thread Index]
Message Nav: [Date Prev] [Date Next] [Thread Prev] [Thread Next]
Index: objdump.c
===================================================================
RCS file: /cvs/src/src/binutils/objdump.c,v
retrieving revision 1.78
diff -u -r1.78 objdump.c
--- objdump.c	7 Oct 2003 08:53:42 -0000	1.78
+++ objdump.c	27 Oct 2003 13:10:56 -0000
@@ -35,16 +35,16 @@
       processed in order by display_bfd().  If the file is an archive each
       of its elements is processed in turn.
       
-   3. The file's target architecture and binary file format are determnined
+   3. The file's target architecture and binary file format are determined
       by bfd_check_format().  If they are recognised, then dump_bfd() is
       called.
 
-   4. dump_bfd() in turn calls seperate functions to display the requested
-      item(s) of infomation(s).  For example dissasemble_data() is called if
+   4. dump_bfd() in turn calls separate functions to display the requested
+      item(s) of information(s).  For example disassemble_data() is called if
       a disassmebly has been requested.
 
    When disassembling the code loops through blocks of instructions bounded
-   by symbols, calling dissassemble_bytes() on each block.  The actual
+   by symbols, calling disassemble_bytes() on each block.  The actual
    disassembling is done by the libopcodes library, via a function pointer
    supplied by the disassembler() function.  */
 
@@ -871,7 +871,7 @@
 static unsigned int prev_line;
 
 /* We keep a list of all files that we have seen when doing a
-   dissassembly with source, so that we know how much of the file to
+   disassembly with source, so that we know how much of the file to
    display.  This can be important for inlined functions.  */
 
 struct print_file_list
@@ -999,7 +999,7 @@
     }
 }
 
 /* Show the line number, or the source line, in a dissassembly
    listing.  */
 
 static void
@@ -1585,7 +1585,7 @@
       rel_pp = paux->dynrelbuf;
       rel_count = paux->dynrelcount;
       /* Dynamic reloc addresses are absolute, non-dynamic are section
-	 relative.  REL_OFFSET specifies the reloc address corresponnding
+	 relative.  REL_OFFSET specifies the reloc address corresponding
 	 to the start of this section.  */
       rel_offset = pinfo->buffer_vma;
     }
@@ -999,7 +999,7 @@
 }
 
-/* Show the line number, or the source line, in a dissassembly
+/* Show the line number, or the source line, in a disassembly
    listing.  */
 